@@ -43,13 +43,6 @@
 #  define EXIT_FAILURE 1
 #endif
 
-typedef int bool;
-#ifndef FALSE
-#  define FALSE 0
-#  define TRUE  1
-#endif
-
-
 /* Returns TRUE if the strings 'a' and 'b' are equal. */
 #define STREQ(a, b) (strcasecmp((a), (b)) == 0)
 
@@ -58,11 +51,9 @@ typedef int bool;
 
 
 inline void
-ErrorLocation( const char *file, int line );
+ErrorLocation(const char *file, int line);
 
-/*@out@*/ /*@only@*/
 void *
-xmalloc( size_t size, const char *filename, int line_number );
-
+xmalloc(size_t size, const char *filename, int line_number);
 
 #endif /* COMMON_H */
