@@ -33,7 +33,7 @@
   "\n" \
   "Written by\n" \
   "Hugo Villeneuve\n" \
-  "Jonathan St-Andr\n" \
+  "Jonathan St-André\n" \
   "Pascal Fecteau"
 
 void
