@@ -22,22 +22,16 @@
 #ifndef PGMWIN_H
 #define PGMWIN_H 1
 
-
 #include <gtk/gtk.h>
 #include "gtksizes.h"
 
-
-#define MAXBP 32
-
-
 GtkWidget *
-pgmwin_init( int width, int height );
+pgmwin_init(int width, int height);
 
 void
-pgmwin_Disasm( void );
+pgmwin_Disasm(void);
 
 int
-pgmwin_IsBreakpoint( unsigned int Address );
-
+pgmwin_IsBreakpoint(unsigned int address);
 
 #endif /* PGMWIN_H */
